import 'package:equatable/equatable.dart';

abstract class RegisterState extends Equatable {
  const RegisterState();

  @override
  List<Object> get props => [];
}

class RegisterInitial extends RegisterState {}

class RegisterLoading extends RegisterState {}

class RegisterSuccess extends RegisterState {}

class RegisterFailure extends RegisterState {
  final String error;

  const RegisterFailure(this.error);

  @override
  List<Object> get props => [error];
}

class RegisterFieldsState extends RegisterState {
  final bool areFieldsFilled;

  const RegisterFieldsState(this.areFieldsFilled);

  @override
  List<Object> get props => [areFieldsFilled];
}
